
# Slot: has sequence location


holds between two genomic entities when the subject can be localized in sequence coordinates on the object. For example, between an exon and a chromosome/contig.

URI: [biolink:has_sequence_location](https://w3id.org/biolink/vocab/has_sequence_location)


## Domain and Range

[GenomicEntity](GenomicEntity.md) &#8594;  <sub>0..\*</sub> [GenomicEntity](GenomicEntity.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | faldo:location |

